package objects

import "git.tebibyte.media/tomo/tomo"
import "git.tebibyte.media/tomo/tomo/canvas"

// Icon displays a single icon.
type Icon struct {
	tomo.Box
	icon tomo.Icon
	size tomo.IconSize
}

func iconSizeString (size tomo.IconSize) string {
	switch size {
	case tomo.IconSizeLarge:  return "large"
	case tomo.IconSizeMedium: return "medium"
	default:                  return "small"
	}
}

// NewIcon creates a new icon from an icon ID.
func NewIcon (icon tomo.Icon, size tomo.IconSize) *Icon {
	this := &Icon {
		Box: tomo.NewBox(),
	}
	this.SetRole(tomo.R("objects", "Icon"))
	this.SetIcon(icon, size)
	this.OnIconSetChange(this.handleIconSetChange)
	return this
}

// SetIcon sets the icon.
func (this *Icon) SetIcon (icon tomo.Icon, size tomo.IconSize) {
	if this.icon == icon { return }
	this.icon = icon
	this.size = size
	this.setTexture(icon.Texture(size))
}

func (this *Icon) handleIconSetChange () {
	this.setTexture(this.icon.Texture(this.size))
}

func (this *Icon) setTexture (texture canvas.Texture) {
	this.SetAttr(tomo.ATexture(texture))
	this.SetAttr(tomo.ATextureMode(tomo.TextureModeCenter))
	if texture == nil {
		this.SetAttr(tomo.AMinimumSize(0, 0))
	} else {
		bounds := texture.Bounds()
		this.SetAttr(tomo.AttrMinimumSize(bounds.Max.Sub(bounds.Min)))
	}
}
