package objects

import "git.tebibyte.media/tomo/tomo"
import "git.tebibyte.media/tomo/tomo/input"
import "git.tebibyte.media/tomo/tomo/event"
import "git.tebibyte.media/tomo/objects/layouts"

// LabelCheckbox is a checkbox with a label.
type LabelCheckbox struct {
	tomo.ContainerBox
	checkbox *Checkbox
	label    *Label
}

// NewLabelCheckbox creates a new labeled checkbox with the specified value and
// label text.
func NewLabelCheckbox (value bool, text string) *LabelCheckbox {
	box := &LabelCheckbox {
		ContainerBox: tomo.NewContainerBox(),
		checkbox:     NewCheckbox(value),
		label:        NewLabel(text),
	}
	box.SetRole(tomo.R("objects", "LabelCheckbox"))
	box.label.SetAttr(tomo.AAlign(tomo.AlignStart, tomo.AlignMiddle))
	box.label.SetSelectable(false)
	box.label.SetFocusable(false)
	box.Add(box.checkbox)
	box.Add(box.label)
	box.SetAttr(tomo.ALayout(layouts.Row { false, true }))

	box.OnButtonDown(box.handleButtonDown)
	box.OnButtonUp(box.handleButtonUp)
	return box
}

// Value returns the value of the checkbox.
func (this *LabelCheckbox) Value () bool {
	return this.checkbox.Value()
}

// SetValue sets the value of the checkbox.
func (this *LabelCheckbox) SetValue (value bool) {
	this.checkbox.SetValue(value)
}

// Toggle toggles the value of the checkbox between true and false.
func (this *LabelCheckbox) Toggle () {
	this.checkbox.Toggle()
}

// OnValueChange specifies a function to be called when the user checks or
// unchecks the checkbox.
func (this *LabelCheckbox) OnValueChange (callback func ()) event.Cookie {
	return this.checkbox.OnValueChange(callback)
}

func (this *LabelCheckbox) handleButtonDown (button input.Button) bool {
	if !isClickingButton(button) { return false }
	return true
}

func (this *LabelCheckbox) handleButtonUp (button input.Button) bool {
	if !isClickingButton(button) { return false }
	if this.Window().MousePosition().In(this.Bounds()) {
		this.checkbox.SetFocused(true)
		this.checkbox.Toggle()
	}
	return true
}
